Learn R Programming

gfoRmulaICE (version 1.1.1)

natural_course: Natural Course

Description

This function specifies the natural course intervention on the treatment variable in data.

Usage

natural_course(data, treat_var)

Value

a vector containing the intervened values of the same size as the number of rows in data.

Arguments

data

a data frame containing the observed data.

treat_var

a string specifying the treatment variable in data.

Examples

Run this code
data <- gfoRmulaICE::compData
natural_course <- natural_course(data = data, treat_var = "A1")

Run the code above in your browser using DataLab