Learn R Programming

gfoRmulaICE (version 1.1.1)

weight: Indicator for the doubly robust ICE estimator

Description

This function identifies the doubly robust ICE estimator. The treatment models could be specified by treat_model.

Usage

weight(treat_model = list())

Value

treatment model specifications and treatment variable names.

Arguments

treat_model

a list of formulas specifying the treatment model for the corresponding treatment variable. The length of list must match the number of treatment variables.