powered by
This function specifies the natural course intervention on the treatment variable in data.
data
natural_course(data, treat_var)
a vector containing the intervened values of the same size as the number of rows in data.
a data frame containing the observed data.
a string specifying the treatment variable in data.
data <- gfoRmulaICE::compData natural_course <- natural_course(data = data, treat_var = "A1")
Run the code above in your browser using DataLab